==> webdis-commands-0.0.3.tgz: package/lib/esm/webdis/commander.js <==
import request from "superagent";
import prefix from "superagent-prefix";
import chalk from "chalk";
const Ok = "OK";
class Commander {
    constructor(url, db) {
        this.db = db;
        this.agent = request
            .agent()
            .use(prefix(url))
            .accept("json");
    }
    makeCommand(command) {
        return this.db !== undefined ? this.db + "/" + command : command;
    }
    async call(url) {
        try {
            const command = this.makeCommand(url);
            const res = await this.agent.post("/").send(command);
            return res.body;
        }
        catch (e) {
            console.error(chalk.red(e));
            return 0;
        }
    }
    async set(key, value) {
        const res = await this.call(`SET/${key}/${value}`);
        return res === 0 ? null : Ok;
    }
    async get(key) {
        const res = await this.call(`GET/${key}`);
        return res === 0 ? null : res.GET;
    }
    async del(key) {
        const res = await this.call(`DEL/${key}`);
        return res === 0 ? null : res.DEL;
    }
    async exists(key) {
        const res = await this.call(`EXISTS/${key}`);
        return res === 0 ? null : res.EXISTS;
    }
    async sadd(key, value) {
        const res = await this.call(`SADD/${key}/${value}`);
        return res === 0 ? null : res.SADD;
    }
    async srem(key, value) {
        const res = await this.call(`SREM/${key}/${value}`);
        return res === 0 ? null : res.SREM;
    }
    async smember(key) {
        const res = await this.call(`SMEMBERS/${key}`);
        return res === 0 ? null : res.SMEMBERS;
    }
    async hset(name, key, value) {
        const res = await this.call(`HSET/${name}/${key}/${encodeURIComponent(value)}`);
        return res === 0 ? null : res.HSET;
    }
    async hget(name, key) {
        const res = await this.call(`HGET/${name}/${key}`);
        return res === 0 ? null : res.HGET;
    }
    async hgetall(name) {
        const res = await this.call(`HGETALL/${name}`);
        return res === 0 ? null : res.HGETALL;
    }
    async hmset(name, key, value) {
        const res = await this.call(`HMSET/${name}/${key}/${value}`);
        return res === 0 ? null : res.HMSET;
    }
    async hmget(name, key) {
        const res = await this.call(`HMGET/${name}/${key}`);
        return res === 0 ? null : res.HMGET;
    }
    async hdel(name, key) {
        const res = await this.call(`HDEL/${name}/${key}`);
        return res === 0 ? null : res.HDEL;
    }
    async sismember(name, key) {
        const res = await this.call(`SISMEMBER/${name}/${key}`);
        return res === 0 ? null : res.SISMEMBER;
    }
    async expire(key, value) {
        const res = await this.call(`EXPIRE/${key}/${value}`);
        return res === 0 ? null : res.EXPIRE;
    }
    async keys(key) {
        const res = await this.call(`KEYS/${key}`);
        return res === 0 ? null : res.KEYS;
    }
    async mget(keys) {
        const res = await this.call(`MGET/${keys.join("/")}`);
        return res === 0 ? null : res.MGET;
    }
    // utility
    async flushdb() {
        const res = await this.call(`FLUSHDB`);
        return res === 0 ? null : res.FLUSHDB;
    }
    async flushall() {
        const res = await this.call(`FLUSHALL`);
        return res === 0 ? null : res.FLUSHALL;
    }
    // subscriptions
    async publish(channel, message) {
        const res = await this.call(`PUBLISH/${channel}/${message}`);
        return res === 0 ? null : res.PUBLISH;
    }
    async unsubscribe(channel) {
        const res = await this.call(`UNSUBSCRIBE/${channel}`);
        return res === 0 ? null : res.UNSUBSCRIBE;
    }
}
export default Commander;

==> webdis-commands-0.0.4.tgz: package/lib/esm/webdis/commander.js <==
import request from "superagent";
import prefix from "superagent-prefix";
import chalk from "chalk";
const Ok = "OK";
class Commander {
    constructor(url, options = {}) {
        this.db = options.db;
        this.agent = request
            .agent()
            .use(prefix(url))
            .accept("json");
        if (options.auth) {
            // apply auth incase it's passed
            this.auth = options.auth.split(":");
        }
    }
    makeCommand(command) {
        return this.db !== undefined ? this.db + "/" + command : command;
    }
    async call(url) {
        try {
            const command = this.makeCommand(url);
            const res = this.auth ?
                await this.agent
                    .auth(this.auth[0], this.auth[1])
                    .post("/")
                    .send(command) :
                await this.agent
                    .post("/")
                    .send(command);
            return res.body;
        }
        catch (e) {
            console.error(chalk.red(e));
            return 0;
        }
    }
    async set(key, value) {
        const res = await this.call(`SET/${key}/${value}`);
        return res === 0 ? null : Ok;
    }
    async get(key) {
        const res = await this.call(`GET/${key}`);
        return res === 0 ? null : res.GET;
    }
    async del(key) {
        const res = await this.call(`DEL/${key}`);
        return res === 0 ? null : res.DEL;
    }
    async exists(key) {
        const res = await this.call(`EXISTS/${key}`);
        return res === 0 ? null : res.EXISTS;
    }
    async sadd(key, value) {
        const res = await this.call(`SADD/${key}/${value}`);
        return res === 0 ? null : res.SADD;
    }
    async srem(key, value) {
        const res = await this.call(`SREM/${key}/${value}`);
        return res === 0 ? null : res.SREM;
    }
    async smember(key) {
        const res = await this.call(`SMEMBERS/${key}`);
        return res === 0 ? null : res.SMEMBERS;
    }
    async hset(name, key, value) {
        const res = await this.call(`HSET/${name}/${key}/${encodeURIComponent(value)}`);
        return res === 0 ? null : res.HSET;
    }
    async hget(name, key) {
        const res = await this.call(`HGET/${name}/${key}`);
        return res === 0 ? null : res.HGET;
    }
    async hgetall(name) {
        const res = await this.call(`HGETALL/${name}`);
        return res === 0 ? null : res.HGETALL;
    }
    async hmset(name, key, value) {
        const res = await this.call(`HMSET/${name}/${key}/${value}`);
        return res === 0 ? null : res.HMSET;
    }
    async hmget(name, key) {
        const res = await this.call(`HMGET/${name}/${key}`);
        return res === 0 ? null : res.HMGET;
    }
    async hdel(name, key) {
        const res = await this.call(`HDEL/${name}/${key}`);
        return res === 0 ? null : res.HDEL;
    }
    async sismember(name, key) {
        const res = await this.call(`SISMEMBER/${name}/${key}`);
        return res === 0 ? null : res.SISMEMBER;
    }
    async expire(key, value) {
        const res = await this.call(`EXPIRE/${key}/${value}`);
        return res === 0 ? null : res.EXPIRE;
    }
    async keys(key) {
        const res = await this.call(`KEYS/${key}`);
        return res === 0 ? null : res.KEYS;
    }
    async mget(keys) {
        const res = await this.call(`MGET/${keys.join("/")}`);
        return res === 0 ? null : res.MGET;
    }
    // utility
    async flushdb() {
        const res = await this.call(`FLUSHDB`);
        return res === 0 ? null : res.FLUSHDB;
    }
    async flushall() {
        const res = await this.call(`FLUSHALL`);
        return res === 0 ? null : res.FLUSHALL;
    }
    async ping() {
        const res = await this.call(`PING`);
        return res === 0 ? null : res.PING;
    }
    // subscriptions
    async publish(channel, message) {
        const res = await this.call(`PUBLISH/${channel}/${message}`);
        return res === 0 ? null : res.PUBLISH;
    }
    async unsubscribe(channel) {
        const res = await this.call(`UNSUBSCRIBE/${channel}`);
        return res === 0 ? null : res.UNSUBSCRIBE;
    }
}
export default Commander;
